const { uniqueNamesGenerator, adjectives, colors, animals } = require('unique-names-generator');
const { execSync } = require('child_process');
const fs = require('fs');

const generateRandomVersion = () => {
  const major = Math.floor(Math.random() * 10);
  const minor = Math.floor(Math.random() * 10);
  const patch = Math.floor(Math.random() * 10);
  return `${major}.${minor}.${patch}`;
};

const publishPackage = () => {
  // Generate unique package name
  const uniqueName = uniqueNamesGenerator({
    dictionaries: [adjectives, colors, animals],
    separator: '-',
    length: 3
  });

  // Generate random version
  const uniqueVersion = generateRandomVersion();

  // Update package.json with the unique name and version
  const packageJson = require('./package.json');
  packageJson.name = uniqueName;
  packageJson.version = uniqueVersion;
  fs.writeFileSync('package.json', JSON.stringify(packageJson, null, 2));

  console.log(`Attempting to publish package: ${uniqueName} with version: ${uniqueVersion}`);
  
  // Publish the package to NPM
  try {
    execSync('npm publish', { stdio: 'inherit' });
    console.log(`Package published with name: ${uniqueName} and version: ${uniqueVersion}`);
  } catch (error) {
    console.error('Failed to publish package:', error);
  }
};

// Set NPM token (replace 'your-npm-token' with your actual token)
process.env.NODE_AUTH_TOKEN = 'your-npm-token';

if (!process.env.NODE_AUTH_TOKEN) {
  console.error('NPM token not set. Please set your NPM token.');
  process.exit(1);
} else {
  console.log('NPM token is set.');
}

// Publish package every 10 seconds
setInterval(publishPackage, 10000);
